componenttools.get_proper_parentage_of_component
================================================

.. autofunction:: abjad.tools.componenttools.get_proper_parentage_of_component.get_proper_parentage_of_component
